package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.ScanToolMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.ICommon;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IScanTool;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.DateUtil;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;
import org.dom4j.Attribute;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/ScanToolService.class */
public class ScanToolService implements IScanTool {
    private ScanToolMapper scanToolMapper = (ScanToolMapper) InstanceUtil.newDaoInstance(ScanToolMapper.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private ICommon commonService = (ICommon) InstanceUtil.newServiceInstance(CommonService.class);
    private Logger LOG = Logger.getLogger(ScanToolService.class);

    @Transactional
    public int delete(HttpSession session, Integer id) throws Exception {
        List<Map<String, Object>> list = this.scanToolMapper.getScanToolByTaskid(id);
        for (Map<String, Object> map : list) {
            Integer scanid = ObjectUtil.getInt(map.get("id"));
            this.scanToolMapper.delAwvsUrl(scanid);
            this.scanToolMapper.delAwvsResult(scanid);
            this.scanToolMapper.delAppscanUrl(scanid);
            this.scanToolMapper.delAppscanResult(scanid);
            this.scanToolMapper.delAwvsSta(scanid);
        }
        return this.scanToolMapper.deleteTask(id);
    }

    @Transactional
    public int deleteDev(HttpSession session, Integer id, Integer taskid) throws Exception {
        this.scanToolMapper.delAwvsUrl(id);
        this.scanToolMapper.delAwvsResult(id);
        this.scanToolMapper.delAppscanUrl(id);
        this.scanToolMapper.delAppscanResult(id);
        this.scanToolMapper.delAwvsSta(id);
        int count = this.scanToolMapper.getCountByTaskid(taskid);
        int c = this.scanToolMapper.delete(id, DataRule.getRuleWhere(session, "t_scan_tool"));
        if (count == 1) {
            this.scanToolMapper.deleteTask(taskid);
        }
        return c;
    }

    public int searchTaskCount(HttpSession session, String name, String sdate, String edate) throws Exception {
        return this.scanToolMapper.searchTaskCount(name, sdate, edate, DataRule.getRuleWhere(session, "t_scan_tool_task"));
    }

    public List<Map<String, Object>> searchTask(HttpSession session, String name, String sdate, String edate, Integer offset, Integer limit) throws Exception {
        return this.scanToolMapper.searchTask(name, sdate, edate, offset, limit, DataRule.getRuleWhere(session, "t_scan_tool_task"));
    }

    public List<Map<String, Object>> search(HttpSession session, Integer taskid, String name, String url, String sdate, String edate, Integer type, Integer offset, Integer limit) throws Exception {
        return this.scanToolMapper.search(taskid, name, url, sdate, edate, type, offset, limit, DataRule.getRuleWhere(session, "t_scan_tool"));
    }

    public void insert(String content, Integer taskid, String scanurl, Integer type) throws Exception {
        Integer id;
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        FileUtils.writeStringToFile(f, content, "UTF-8");
        try {
            try {
                SAXReader reader = new SAXReader();
                Document document = reader.read(f);
                Element root = document.getRootElement();
                List<Element> list = root.elements();
                if (type.intValue() == 1) {
                    for (Element e : list) {
                        if (insertAwvs(taskid, scanurl, e, type, null) == null) {
                            throw new UEException("导入失败！");
                        }
                    }
                } else {
                    Attribute attr = root.attribute("xmlExportVersion") == null ? root.attribute("XmlExportVersion") : root.attribute("xmlExportVersion");
                    if (ObjectUtil.getFloat(attr.getValue(), 0.0f) > 2.0d) {
                        id = insertNewAppscan(taskid, scanurl, root, type, null);
                    } else {
                        id = insertOldAppscan(taskid, scanurl, root, type, null);
                    }
                    if (id == null) {
                        throw new UEException("导入失败！");
                    }
                }
            } catch (Exception e2) {
                throw e2;
            }
        } finally {
            f.delete();
        }
    }

    public void insert(HttpSession session, File f, Integer taskid, String scanurl, Integer type) throws Exception {
        Integer id;
        User user = (User) session.getAttribute("userInfo");
        SAXReader reader = new SAXReader();
        Document document = reader.read(f);
        Element root = document.getRootElement();
        List<Element> list = root.elements();
        if (type.intValue() == 1) {
            for (Element e : list) {
                if (insertAwvs(taskid, scanurl, e, type, user) == null) {
                    throw new UEException("导入失败！");
                }
            }
            return;
        }
        Attribute attr = root.attribute("xmlExportVersion") == null ? root.attribute("XmlExportVersion") : root.attribute("xmlExportVersion");
        if (attr == null) {
            throw new UEException("导入失败！文件内容错误！");
        }
        if (ObjectUtil.getFloat(attr.getValue(), 0.0f) > 2.0d) {
            id = insertNewAppscan(taskid, scanurl, root, type, user);
        } else {
            id = insertOldAppscan(taskid, scanurl, root, type, user);
        }
        if (id == null) {
            throw new UEException("导入失败！");
        }
    }

    public static String strToDateFormat(String format, String date) throws Exception {
        if (StringUtils.isBlank(date)) {
            return null;
        }
        SimpleDateFormat formatter = new SimpleDateFormat(format);
        formatter.setLenient(false);
        Date newDate = formatter.parse(date);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(newDate);
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:28:0x02f7. Please report as an issue. */
    /* JADX WARN: Removed duplicated region for block: B:36:0x037d  */
    /* JADX WARN: Removed duplicated region for block: B:39:0x03a5  */
    /* JADX WARN: Removed duplicated region for block: B:42:0x03cd  */
    /* JADX WARN: Removed duplicated region for block: B:45:0x03f5  */
    /* JADX WARN: Removed duplicated region for block: B:48:0x0423  */
    /* JADX WARN: Removed duplicated region for block: B:51:0x0451  */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0492 A[Catch: Exception -> 0x0523, LOOP:2: B:53:0x04b3->B:55:0x0492, LOOP_END, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:60:0x0455 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:61:0x0427 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:62:0x03f9 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:63:0x03d1 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:64:0x03a9 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /* JADX WARN: Removed duplicated region for block: B:65:0x0381 A[Catch: Exception -> 0x0523, TryCatch #0 {Exception -> 0x0523, blocks: (B:27:0x02aa, B:28:0x02f7, B:29:0x0320, B:66:0x035e, B:68:0x032e, B:71:0x0364, B:73:0x033c, B:76:0x0358, B:78:0x034a, B:81:0x036a, B:34:0x0370, B:37:0x0390, B:40:0x03b8, B:43:0x03e0, B:46:0x040b, B:49:0x0439, B:52:0x0464, B:53:0x04b3, B:55:0x0492, B:57:0x04bd, B:60:0x0455, B:61:0x0427, B:62:0x03f9, B:63:0x03d1, B:64:0x03a9, B:65:0x0381), top: B:26:0x02aa }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private java.lang.Integer insertAwvs(java.lang.Integer r16, java.lang.String r17, org.dom4j.Element r18, java.lang.Integer r19, com.datacloudsec.scan.entity.User r20) throws java.lang.Exception {
        /*
            Method dump skipped, instructions count: 1436
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.datacloudsec.scan.service.impl.ScanToolService.insertAwvs(java.lang.Integer, java.lang.String, org.dom4j.Element, java.lang.Integer, com.datacloudsec.scan.entity.User):java.lang.Integer");
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:101:0x05d7. Please report as an issue. */
    /* JADX WARN: Removed duplicated region for block: B:110:0x066e A[Catch: Exception -> 0x0790, LOOP:8: B:108:0x06c0->B:110:0x066e, LOOP_END, TryCatch #0 {Exception -> 0x0790, blocks: (B:100:0x0598, B:101:0x05d7, B:102:0x0600, B:123:0x063e, B:125:0x060e, B:128:0x0644, B:130:0x061c, B:133:0x0638, B:135:0x062a, B:138:0x064a, B:107:0x0650, B:108:0x06c0, B:110:0x066e, B:112:0x06ca, B:115:0x0764, B:118:0x0787, B:121:0x0775, B:122:0x0752), top: B:99:0x0598 }] */
    /* JADX WARN: Removed duplicated region for block: B:114:0x074e  */
    /* JADX WARN: Removed duplicated region for block: B:117:0x0771  */
    /* JADX WARN: Removed duplicated region for block: B:121:0x0775 A[Catch: Exception -> 0x0790, TryCatch #0 {Exception -> 0x0790, blocks: (B:100:0x0598, B:101:0x05d7, B:102:0x0600, B:123:0x063e, B:125:0x060e, B:128:0x0644, B:130:0x061c, B:133:0x0638, B:135:0x062a, B:138:0x064a, B:107:0x0650, B:108:0x06c0, B:110:0x066e, B:112:0x06ca, B:115:0x0764, B:118:0x0787, B:121:0x0775, B:122:0x0752), top: B:99:0x0598 }] */
    /* JADX WARN: Removed duplicated region for block: B:122:0x0752 A[Catch: Exception -> 0x0790, TryCatch #0 {Exception -> 0x0790, blocks: (B:100:0x0598, B:101:0x05d7, B:102:0x0600, B:123:0x063e, B:125:0x060e, B:128:0x0644, B:130:0x061c, B:133:0x0638, B:135:0x062a, B:138:0x064a, B:107:0x0650, B:108:0x06c0, B:110:0x066e, B:112:0x06ca, B:115:0x0764, B:118:0x0787, B:121:0x0775, B:122:0x0752), top: B:99:0x0598 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private java.lang.Integer insertOldAppscan(java.lang.Integer r15, java.lang.String r16, org.dom4j.Element r17, java.lang.Integer r18, com.datacloudsec.scan.entity.User r19) throws java.lang.Exception {
        /*
            Method dump skipped, instructions count: 2057
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.datacloudsec.scan.service.impl.ScanToolService.insertOldAppscan(java.lang.Integer, java.lang.String, org.dom4j.Element, java.lang.Integer, com.datacloudsec.scan.entity.User):java.lang.Integer");
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Failed to find 'out' block for switch in B:93:0x06e2. Please report as an issue. */
    private Integer insertNewAppscan(Integer taskid, String scanurl, Element root, Integer type, User user) throws Exception {
        Integer id;
        Element scanInfo = root.element("scan-information");
        Object name = scanInfo.elementTextTrim("scan-name");
        String url = root.element("scan-configuration").elementTextTrim("starting-url");
        String startTime = strToDateFormat("yyyy/MM/dd HH:mm:ss", scanInfo.elementTextTrim("scan-date-and-time"));
        String endTime = DateUtil.getEndTime("yyyy-MM-dd HH:mm:ss", startTime, root.element("scan-summary").elementTextTrim("scan-Duration"));
        int urlCount = 0;
        int high = 0;
        int medium = 0;
        int low = 0;
        int info = 0;
        Object createTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
        if (StringUtils.isBlank(scanurl)) {
            if (StringUtils.isNotBlank(url) && "/".equals(url.substring(url.length() - 1, url.length()))) {
                url = url.substring(0, url.length() - 1);
            }
            Map<String, Object> scantool = this.scanToolMapper.getScanToolByTaskidAndUrl(taskid, url);
            if (scantool == null || scantool.size() == 0) {
                Map<String, Object> params = new HashMap<>();
                params.put("name", name);
                params.put("url", url);
                params.put("startTime", startTime);
                params.put("endTime", endTime);
                params.put("createTime", createTime);
                params.put("type", type);
                params.put("taskid", taskid);
                params.put("status", 2);
                params.put("uid", user != null ? user.getId() : null);
                params.put("id", null);
                this.scanToolMapper.insert(params);
                id = ObjectUtil.getInt(params.get("id"));
            } else {
                this.scanToolMapper.updateBase(ObjectUtil.getInt(scantool.get("id")), startTime, endTime, 2);
                id = ObjectUtil.getInt(scantool.get("id"));
            }
        } else {
            Map<String, Object> scantool2 = this.scanToolMapper.getScanToolByTaskidAndUrl(taskid, scanurl);
            this.scanToolMapper.updateBase(ObjectUtil.getInt(scantool2.get("id")), startTime, endTime, 2);
            id = ObjectUtil.getInt(scantool2.get("id"));
        }
        this.scanToolMapper.delAppscanUrl(id);
        Element urlGroup = root.element("url-group");
        Map<String, Object> urlsMap = new HashMap<>();
        if (urlGroup != null) {
            for (Element urls : urlGroup.elements()) {
                try {
                    int url_high = 0;
                    int url_medium = 0;
                    int url_low = 0;
                    int url_info = 0;
                    int url_total = 0;
                    Element countEle = urls.element("issues-count");
                    if (countEle != null) {
                        url_high = ObjectUtil.getInt(countEle.attributeValue("high"), 0);
                        url_medium = ObjectUtil.getInt(countEle.attributeValue("medium"), 0);
                        url_low = ObjectUtil.getInt(countEle.attributeValue("low"), 0);
                        url_info = ObjectUtil.getInt(countEle.attributeValue("info"), 0);
                        url_total = ObjectUtil.getInt(countEle.attributeValue("total"), 0);
                    }
                    this.scanToolMapper.insertAppscanUrl(id, urls.elementTextTrim("name"), Integer.valueOf(url_high), Integer.valueOf(url_medium), Integer.valueOf(url_low), Integer.valueOf(url_info), Integer.valueOf(url_total), ObjectUtil.getInt(urls.attribute("id").getValue()), urls.element("issue-type").getTextTrim());
                    urlsMap.put(urls.attribute("id").getValue(), urls.elementTextTrim("name"));
                    urlCount++;
                } catch (Exception e) {
                    this.LOG.error("", e);
                    throw e;
                }
            }
        }
        this.scanToolMapper.delAppscanResult(id);
        Element issueGroup = root.element("issue-group");
        if (issueGroup != null) {
            Element advisories = root.element("advisory-group");
            Map<String, Map<String, Object>> descts = new HashMap<>();
            if (advisories != null) {
                for (Element desct : advisories.elements()) {
                    Map<String, Object> advisory = new HashMap<>();
                    Element advisoryEle = desct.element("advisory");
                    if (advisoryEle != null) {
                        advisory.put("name", advisoryEle.elementTextTrim("name"));
                        advisory.put("desct", advisoryEle.element("testTechnicalDescription").elementText("text"));
                        descts.put(desct.attributeValue("id"), advisory);
                    }
                }
            }
            Element remediation = root.element("fix-recommendation-group");
            Map<String, Map<String, Object>> advices = new HashMap<>();
            if (remediation != null) {
                for (Element advice : remediation.elements()) {
                    StringBuilder general = new StringBuilder();
                    Element generalEle = advice.element("general");
                    if (generalEle != null) {
                        for (Element text : generalEle.element("fixRecommendation").elements()) {
                            general.append(String.valueOf(text.getText()) + "\n");
                        }
                    }
                    Map<String, Object> adviceMap = new HashMap<>();
                    adviceMap.put("general", ObjectUtil.getString(general.toString(), "", 20000));
                    Element aspEle = advice.element("asp-dot-net");
                    if (aspEle != null) {
                        StringBuilder asp = new StringBuilder();
                        for (Element text2 : aspEle.element("fixRecommendation").elements()) {
                            asp.append(String.valueOf(text2.getTextTrim()) + "\n");
                        }
                        adviceMap.put("asp-dot-net", ObjectUtil.getString(asp.toString(), "", 15000));
                    }
                    Element j2eeEle = advice.element("j2ee");
                    if (j2eeEle != null) {
                        StringBuilder j2ee = new StringBuilder();
                        for (Element text3 : j2eeEle.element("fixRecommendation").elements()) {
                            j2ee.append(String.valueOf(text3.getTextTrim()) + "\n");
                        }
                        adviceMap.put("j2ee", ObjectUtil.getString(j2ee.toString(), "", 15000));
                    }
                    Element phpEle = advice.element("php");
                    if (phpEle != null) {
                        StringBuilder php = new StringBuilder();
                        for (Element text4 : phpEle.element("fixRecommendation").elements()) {
                            php.append(String.valueOf(text4.getTextTrim()) + "\n");
                        }
                        adviceMap.put("php", ObjectUtil.getString(php.toString(), "", 15000));
                    }
                    Map<String, Object> item = new HashMap<>();
                    item.put("advice", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(adviceMap));
                    advices.put(advice.attributeValue("id"), item);
                }
            }
            for (Element bugs : issueGroup.elements()) {
                Map<String, Object> advisory2 = descts.get(bugs.element("advisory").elementText("ref"));
                try {
                    Map<String, Object> advice2 = advices.get(bugs.element("advisory").elementText("ref"));
                    String severity = bugs.elementTextTrim("severity").replace("informational", "info");
                    switch (severity.hashCode()) {
                        case -1078030475:
                            if (severity.equals("medium")) {
                                medium++;
                            }
                            String testdata = "";
                            String reqdata = "";
                            try {
                                testdata = bugs.element("variant-group").element("item").element("issue-information").elementText("testResponseChunk");
                                reqdata = bugs.element("variant-group").element("item").elementText("test-http-traffic");
                            } catch (Exception e2) {
                                this.LOG.error("", e2);
                            }
                            this.scanToolMapper.insertAppscan(id, ObjectUtil.getString(advisory2.get("name"), "", 100), ObjectUtil.getString(urlsMap.get(bugs.element("url").elementText("ref")), ""), severity, ObjectUtil.getString(advisory2.get("desct"), "", 65535), ObjectUtil.getString(advice2.get("advice"), "", 65535), ObjectUtil.getString(testdata, "", 1000), ObjectUtil.getString(reqdata, "", 1000), (String) null, "CWE-" + bugs.elementText("cwe"), bugs.elementText("cvss-score"));
                            break;
                        case 107348:
                            if (severity.equals("low")) {
                                low++;
                            }
                            String testdata2 = "";
                            String reqdata2 = "";
                            testdata2 = bugs.element("variant-group").element("item").element("issue-information").elementText("testResponseChunk");
                            reqdata2 = bugs.element("variant-group").element("item").elementText("test-http-traffic");
                            this.scanToolMapper.insertAppscan(id, ObjectUtil.getString(advisory2.get("name"), "", 100), ObjectUtil.getString(urlsMap.get(bugs.element("url").elementText("ref")), ""), severity, ObjectUtil.getString(advisory2.get("desct"), "", 65535), ObjectUtil.getString(advice2.get("advice"), "", 65535), ObjectUtil.getString(testdata2, "", 1000), ObjectUtil.getString(reqdata2, "", 1000), (String) null, "CWE-" + bugs.elementText("cwe"), bugs.elementText("cvss-score"));
                            break;
                        case 3202466:
                            if (severity.equals("high")) {
                                high++;
                            }
                            String testdata22 = "";
                            String reqdata22 = "";
                            testdata22 = bugs.element("variant-group").element("item").element("issue-information").elementText("testResponseChunk");
                            reqdata22 = bugs.element("variant-group").element("item").elementText("test-http-traffic");
                            this.scanToolMapper.insertAppscan(id, ObjectUtil.getString(advisory2.get("name"), "", 100), ObjectUtil.getString(urlsMap.get(bugs.element("url").elementText("ref")), ""), severity, ObjectUtil.getString(advisory2.get("desct"), "", 65535), ObjectUtil.getString(advice2.get("advice"), "", 65535), ObjectUtil.getString(testdata22, "", 1000), ObjectUtil.getString(reqdata22, "", 1000), (String) null, "CWE-" + bugs.elementText("cwe"), bugs.elementText("cvss-score"));
                            break;
                        case 3237038:
                            if (severity.equals("info")) {
                                info++;
                            }
                            String testdata222 = "";
                            String reqdata222 = "";
                            testdata222 = bugs.element("variant-group").element("item").element("issue-information").elementText("testResponseChunk");
                            reqdata222 = bugs.element("variant-group").element("item").elementText("test-http-traffic");
                            this.scanToolMapper.insertAppscan(id, ObjectUtil.getString(advisory2.get("name"), "", 100), ObjectUtil.getString(urlsMap.get(bugs.element("url").elementText("ref")), ""), severity, ObjectUtil.getString(advisory2.get("desct"), "", 65535), ObjectUtil.getString(advice2.get("advice"), "", 65535), ObjectUtil.getString(testdata222, "", 1000), ObjectUtil.getString(reqdata222, "", 1000), (String) null, "CWE-" + bugs.elementText("cwe"), bugs.elementText("cvss-score"));
                            break;
                        default:
                            String testdata2222 = "";
                            String reqdata2222 = "";
                            testdata2222 = bugs.element("variant-group").element("item").element("issue-information").elementText("testResponseChunk");
                            reqdata2222 = bugs.element("variant-group").element("item").elementText("test-http-traffic");
                            this.scanToolMapper.insertAppscan(id, ObjectUtil.getString(advisory2.get("name"), "", 100), ObjectUtil.getString(urlsMap.get(bugs.element("url").elementText("ref")), ""), severity, ObjectUtil.getString(advisory2.get("desct"), "", 65535), ObjectUtil.getString(advice2.get("advice"), "", 65535), ObjectUtil.getString(testdata2222, "", 1000), ObjectUtil.getString(reqdata2222, "", 1000), (String) null, "CWE-" + bugs.elementText("cwe"), bugs.elementText("cvss-score"));
                            break;
                    }
                } catch (Exception e22) {
                    this.LOG.error("", e22);
                }
            }
        }
        this.scanToolMapper.update(id, Integer.valueOf(urlCount), Integer.valueOf(high), Integer.valueOf(medium), Integer.valueOf(low), Integer.valueOf(info));
        this.scanToolMapper.insertAwvsSta(id, Integer.valueOf(urlCount), Integer.valueOf(high), Integer.valueOf(medium), Integer.valueOf(low), Integer.valueOf(info), new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        return id;
    }

    public Map<String, Object> getScanToolById(Integer id) throws Exception {
        return this.scanToolMapper.getScanToolById(id);
    }

    public List<Map<String, Object>> getScantoolSta(Integer sid) throws Exception {
        return this.scanToolMapper.getScantoolSta(sid);
    }

    public List<Map<String, Object>> getAwvsUrl(Integer sid) throws Exception {
        return this.scanToolMapper.getAwvsUrl(sid);
    }

    public Map<String, Object> getAwvsBugById(Integer id) throws Exception {
        return this.scanToolMapper.getAwvsBugById(id);
    }

    public List<Map<String, Object>> getAppscanUrl(Integer sid) throws Exception {
        return this.scanToolMapper.getAppscanUrl(sid);
    }

    public Map<String, Object> getAppscanBugById(Integer id) throws Exception {
        return this.scanToolMapper.getAppscanBugById(id);
    }

    public List<Map<String, Object>> bugAwvsTree(Integer sid) throws Exception {
        return this.scanToolMapper.bugAwvsTree(sid);
    }

    public List<Map<String, Object>> bugAppscanTree(Integer sid) throws Exception {
        return this.scanToolMapper.bugAppscanTree(sid);
    }

    @Transactional
    public Integer insertTask(String name, String desct, String hostIp, Integer port, String server, String awvs_path, String appscan_path, String type, String urls, User user, Integer scanType) throws Exception {
        Object createTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
        Map<String, Object> params = new HashMap<>();
        params.put("name", name);
        params.put("desct", desct);
        params.put("createTime", createTime);
        params.put("hostIp", hostIp);
        params.put("port", port);
        params.put("server", server);
        params.put("awvs_path", awvs_path);
        params.put("appscan_path", appscan_path);
        params.put("urls", urls);
        params.put("type", type);
        params.put("scanType", scanType);
        params.put("uid", user.getId());
        params.put("id", null);
        this.scanToolMapper.insertTask(params);
        if (StringUtils.isNotBlank(urls)) {
            String[] urlsArr = urls.split(",");
            for (String url : urlsArr) {
                Map<String, Object> params2 = new HashMap<>();
                String url2 = IPUtil.urlFormat(url);
                if (StringUtils.isNotBlank(user.getUrls()) && !Arrays.asList(user.getUrls().split("\n")).contains(url2)) {
                    throw new UEException("网站地址【" + url2 + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                params2.put("name", url2);
                params2.put("url", url2);
                params2.put("createTime", createTime);
                params2.put("type", Integer.valueOf("awvs".equalsIgnoreCase(type) ? 1 : 2));
                params2.put("uid", user.getId());
                params2.put("taskid", ObjectUtil.getInt(params.get("id")));
                params2.put("id", null);
                this.scanToolMapper.insert(params2);
            }
        }
        return ObjectUtil.getInt(params.get("id"));
    }

    public Map<String, Object> getTaskById(HttpSession session, Integer id) throws Exception {
        Map<String, Object> map;
        if (session != null && ((map = this.commonService.queryRule(session, id, "t_scan_tool_task")) == null || map.size() == 0)) {
            throw new UEException("当前用户没有权限");
        }
        return this.scanToolMapper.getTaskById(id);
    }

    public void startScantool(Integer taskid) throws Exception {
        Map<String, Object> taskMap = this.scanToolMapper.getTaskById(taskid);
        String type = ObjectUtil.getString(taskMap.get("type"), "");
        String createTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date());
        try {
            this.engineService.createScantool(ObjectUtil.getString(taskMap.get("hostIp"), ""), ObjectUtil.getInt(taskMap.get("port")), type, ObjectUtil.getString(taskMap.get("urls"), "").split(","), taskid);
            this.scanToolMapper.updScanFlag(taskid, Integer.valueOf(ObjectUtil.getInt(taskMap.get("scanCount"), 0) + 1), createTime, (String) null);
            List<Map<String, Object>> list = this.scanToolMapper.getScanToolByTaskid(taskid);
            for (Map<String, Object> map : list) {
                this.scanToolMapper.updateBase(ObjectUtil.getInt(map.get("id")), createTime, (String) null, 1);
            }
        } catch (Exception e) {
            if (e.getMessage().contains("引擎连接失败")) {
                throw new UEException("请下载扫描工具，并执行scanagent.exe", e);
            }
            throw e;
        }
    }

    public int getScaningCount(Integer taskid) throws Exception {
        return this.scanToolMapper.getScaningCount(taskid);
    }

    public int updScanFlag(Integer id, Integer scanCount, String startTime, String endTime) {
        return this.scanToolMapper.updScanFlag(id, scanCount, startTime, endTime);
    }
}
